==> gorilla-notebook-0.4.0.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.editor.editor_support.js <==
goog.provide('pinkgorilla.editor.editor_support');
goog.require('cljs.core');
goog.require('pinkgorilla.editor.parinfer');
if((typeof pinkgorilla !== 'undefined') && (typeof pinkgorilla.editor !== 'undefined') && (typeof pinkgorilla.editor.editor_support !== 'undefined') && (typeof pinkgorilla.editor.editor_support.state !== 'undefined')){
} else {
pinkgorilla.editor.editor_support.state = cljs.core.atom.cljs$core$IFn$_invoke$arity$1(cljs.core.PersistentArrayMap.EMPTY);
}

/**
 * Custom data/methods for a CodeMirror editor.
 * @interface
 */
pinkgorilla.editor.editor_support.IEditor = function(){};

pinkgorilla.editor.editor_support.frame_updated_QMARK_ = (function pinkgorilla$editor$editor_support$frame_updated_QMARK_(this$){
if((((!((this$ == null)))) && ((!((this$.pinkgorilla$editor$editor_support$IEditor$frame_updated_QMARK_$arity$1 == null)))))){
return this$.pinkgorilla$editor$editor_support$IEditor$frame_updated_QMARK_$arity$1(this$);
} else {
var x__4487__auto__ = (((this$ == null))?null:this$);
var m__4488__auto__ = (pinkgorilla.editor.editor_support.frame_updated_QMARK_[goog.typeOf(x__4487__auto__)]);
if((!((m__4488__auto__ == null)))){
return (m__4488__auto__.cljs$core$IFn$_invoke$arity$1 ? m__4488__auto__.cljs$core$IFn$_invoke$arity$1(this$) : m__4488__auto__.call(null,this$));
} else {
var m__4485__auto__ = (pinkgorilla.editor.editor_support.frame_updated_QMARK_["_"]);
if((!((m__4485__auto__ == null)))){
return (m__4485__auto__.cljs$core$IFn$_invoke$arity$1 ? m__4485__auto__.cljs$core$IFn$_invoke$arity$1(this$) : m__4485__auto__.call(null,this$));
} else {
throw cljs.core.missing_protocol("IEditor.frame-updated?",this$);
}
}
}
});

pinkgorilla.editor.editor_support.set_frame_updated_BANG_ = (function pinkgorilla$editor$editor_support$set_frame_updated_BANG_(this$,value){
if((((!((this$ == null)))) && ((!((this$.pinkgorilla$editor$editor_support$IEditor$set_frame_updated_BANG_$arity$2 == null)))))){
return this$.pinkgorilla$editor$editor_support$IEditor$set_frame_updated_BANG_$arity$2(this$,value);
} else {
var x__4487__auto__ = (((this$ == null))?null:this$);
var m__4488__auto__ = (pinkgorilla.editor.editor_support.set_frame_updated_BANG_[goog.typeOf(x__4487__auto__)]);
if((!((m__4488__auto__ == null)))){
return (m__4488__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4488__auto__.cljs$core$IFn$_invoke$arity$2(this$,value) : m__4488__auto__.call(null,this$,value));
} else {
var m__4485__auto__ = (pinkgorilla.editor.editor_support.set_frame_updated_BANG_["_"]);
if((!((m__4485__auto__ == null)))){
return (m__4485__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4485__auto__.cljs$core$IFn$_invoke$arity$2(this$,value) : m__4485__auto__.call(null,this$,value));
} else {
throw cljs.core.missing_protocol("IEditor.set-frame-updated!",this$);
}
}
}
});

pinkgorilla.editor.editor_support.compute_cursor_dx = (function pinkgorilla$editor$editor_support$compute_cursor_dx(cursor,change){
if(cljs.core.truth_(change)){
var ignore_QMARK_ = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("+indenthack",change.origin);
if(ignore_QMARK_){
return (0);
} else {
var start_x = change.to.ch;
var new_lines = change.text;
var len_last_line = cljs.core.count(cljs.core.last(new_lines));
var end_x = (((cljs.core.count(new_lines) > (1)))?len_last_line:(len_last_line + change.from.ch));
return (end_x - start_x);
}
} else {
return null;
}
});
pinkgorilla.editor.editor_support.compute_cm_change = (function pinkgorilla$editor$editor_support$compute_cm_change(cm,change,options,prev_state){
var map__17217 = (cljs.core.truth_(change)?new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"start-line","start-line",-41746654),change.from.line,new cljs.core.Keyword(null,"end-line","end-line",1837326455),(change.to.line + (1)),new cljs.core.Keyword(null,"num-new-lines","num-new-lines",-1319642646),change.text.length], null):(function (){var start = new cljs.core.Keyword(null,"cursor-line","cursor-line",-1089611007).cljs$core$IFn$_invoke$arity$1(prev_state);
var end = (start + (1));
return new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"start-line","start-line",-41746654),start,new cljs.core.Keyword(null,"end-line","end-line",1837326455),end,new cljs.core.Keyword(null,"num-new-lines","num-new-lines",-1319642646),(end - start)], null);
})());
var map__17217__$1 = (((((!((map__17217 == null))))?(((((map__17217.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__17217.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__17217):map__17217);
var start_line = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__17217__$1,new cljs.core.Keyword(null,"start-line","start-line",-41746654));
var end_line = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__17217__$1,new cljs.core.Keyword(null,"end-line","end-line",1837326455));
var num_new_lines = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__17217__$1,new cljs.core.Keyword(null,"num-new-lines","num-new-lines",-1319642646));
var lines = (function (){var iter__4582__auto__ = (function pinkgorilla$editor$editor_support$compute_cm_change_$_iter__17219(s__17220){
return (new cljs.core.LazySeq(null,(function (){
var s__17220__$1 = s__17220;
while(true){
var temp__5735__auto__ = cljs.core.seq(s__17220__$1);
if(temp__5735__auto__){
var s__17220__$2 = temp__5735__auto__;
if(cljs.core.chunked_seq_QMARK_(s__17220__$2)){
var c__4580__auto__ = cljs.core.chunk_first(s__17220__$2);
var size__4581__auto__ = cljs.core.count(c__4580__auto__);
var b__17222 = cljs.core.chunk_buffer(size__4581__auto__);
if((function (){var i__17221 = (0);
while(true){
if((i__17221 < size__4581__auto__)){
var i = cljs.core._nth.cljs$core$IFn$_invoke$arity$2(c__4580__auto__,i__17221);
cljs.core.chunk_append(b__17222,cm.getLine(i));

var G__17232 = (i__17221 + (1));
i__17221 = G__17232;
continue;
} else {
return true;
}
break;
}
})()){
return cljs.core.chunk_cons(cljs.core.chunk(b__17222),pinkgorilla$editor$editor_support$compute_cm_change_$_iter__17219(cljs.core.chunk_rest(s__17220__$2)));
} else {
return cljs.core.chunk_cons(cljs.core.chunk(b__17222),null);
}
} else {
var i = cljs.core.first(s__17220__$2);
return cljs.core.cons(cm.getLine(i),pinkgorilla$editor$editor_support$compute_cm_change_$_iter__17219(cljs.core.rest(s__17220__$2)));
}
} else {
return null;
}
break;
}
}),null,null));
});
return iter__4582__auto__(cljs.core.range.cljs$core$IFn$_invoke$arity$2(start_line,(start_line + num_new_lines)));
})();
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"line-no","line-no",-666819466),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [start_line,end_line], null),new cljs.core.Keyword(null,"new-line","new-line",1060819447),lines], null);
});
/**
 * Correctly format the text from the given editor.
 * @param {CodeMirror} cm
 */
pinkgorilla.editor.editor_support.fix_text_BANG_ = (function pinkgorilla$editor$editor_support$fix_text_BANG_(var_args){
var args__4795__auto__ = [];
var len__4789__auto___17233 = arguments.length;
var i__4790__auto___17234 = (0);
while(true){
if((i__4790__auto___17234 < len__4789__auto___17233)){
args__4795__auto__.push((arguments[i__4790__auto___17234]));

var G__17235 = (i__4790__auto___17234 + (1));
i__4790__auto___17234 = G__17235;
continue;
} else {
}
break;
}

var argseq__4796__auto__ = ((((1) < args__4795__auto__.length))?(new cljs.core.IndexedSeq(args__4795__auto__.slice((1)),(0),null)):null);
return pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4796__auto__);
});

(pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$core$IFn$_invoke$arity$variadic = (function (cm,p__17225){
var map__17226 = p__17225;
var map__17226__$1 = (((((!((map__17226 == null))))?(((((map__17226.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__17226.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__17226):map__17226);
var change = cljs.core.get.cljs$core$IFn$_invoke$arity$3(map__17226__$1,new cljs.core.Keyword(null,"change","change",-1163046502),null);
var use_cache_QMARK_ = cljs.core.get.cljs$core$IFn$_invoke$arity$3(map__17226__$1,new cljs.core.Keyword(null,"use-cache?","use-cache?",-81331778),false);
var current_text = cm.getValue();
var selection_QMARK_ = cm.somethingSelected();
var selections = cm.listSelections();
var cursor = cm.getCursor();
var scroller = cm.getScrollerElement();
var scroll_x = scroller.scrollLeft;
var scroll_y = scroller.scrollTop;
var options = new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"cursor-line","cursor-line",-1089611007),cursor.line,new cljs.core.Keyword(null,"cursor-x","cursor-x",475204266),cursor.ch,new cljs.core.Keyword(null,"cursor-dx","cursor-dx",133069327),pinkgorilla.editor.editor_support.compute_cursor_dx(cursor,change)], null);
var options__$1 = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([options,cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(pinkgorilla.editor.editor_support.state),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"options","options",99638489)], null))], 0));
var mode = (function (){var or__4185__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(pinkgorilla.editor.editor_support.state),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"mode","mode",654403691)], null));
if(cljs.core.truth_(or__4185__auto__)){
return or__4185__auto__;
} else {
return new cljs.core.Keyword(null,"indent-mode","indent-mode",1737814542);
}
})();
var result = (function (){var G__17228 = mode;
var G__17228__$1 = (((G__17228 instanceof cljs.core.Keyword))?G__17228.fqn:null);
switch (G__17228__$1) {
case "indent-mode":
return pinkgorilla.editor.parinfer.indent_mode.cljs$core$IFn$_invoke$arity$2(current_text,options__$1);

break;
case "paren-mode":
return pinkgorilla.editor.parinfer.paren_mode.cljs$core$IFn$_invoke$arity$2(current_text,options__$1);

break;
default:
return null;

}
})();
var new_text = new cljs.core.Keyword(null,"text","text",-1790561697).cljs$core$IFn$_invoke$arity$1(result);
var new_cursor_x = new cljs.core.Keyword(null,"cursor-x","cursor-x",475204266).cljs$core$IFn$_invoke$arity$1(result);
cm.setValue(new_text);

if(cljs.core.truth_(selection_QMARK_)){
cm.setSelections(selections);
} else {
cm.setCursor((cursor["line"]),new_cursor_x);
}

return cm.scrollTo(scroll_x,scroll_y);
}));

(pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$lang$maxFixedArity = (1));

/** @this {Function} */
(pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$lang$applyTo = (function (seq17223){
var G__17224 = cljs.core.first(seq17223);
var seq17223__$1 = cljs.core.next(seq17223);
var self__4776__auto__ = this;
return self__4776__auto__.cljs$core$IFn$_invoke$arity$variadic(G__17224,seq17223__$1);
}));


//# sourceMappingURL=pinkgorilla.editor.editor_support.js.map

==> gorilla-notebook-0.4.3.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.editor.editor_support.js <==
goog.provide('pinkgorilla.editor.editor_support');
goog.require('cljs.core');
goog.require('pinkgorilla.editor.parinfer');
if((typeof pinkgorilla !== 'undefined') && (typeof pinkgorilla.editor !== 'undefined') && (typeof pinkgorilla.editor.editor_support !== 'undefined') && (typeof pinkgorilla.editor.editor_support.state !== 'undefined')){
} else {
pinkgorilla.editor.editor_support.state = cljs.core.atom.cljs$core$IFn$_invoke$arity$1(cljs.core.PersistentArrayMap.EMPTY);
}

/**
 * Custom data/methods for a CodeMirror editor.
 * @interface
 */
pinkgorilla.editor.editor_support.IEditor = function(){};

pinkgorilla.editor.editor_support.frame_updated_QMARK_ = (function pinkgorilla$editor$editor_support$frame_updated_QMARK_(this$){
if((((!((this$ == null)))) && ((!((this$.pinkgorilla$editor$editor_support$IEditor$frame_updated_QMARK_$arity$1 == null)))))){
return this$.pinkgorilla$editor$editor_support$IEditor$frame_updated_QMARK_$arity$1(this$);
} else {
var x__4487__auto__ = (((this$ == null))?null:this$);
var m__4488__auto__ = (pinkgorilla.editor.editor_support.frame_updated_QMARK_[goog.typeOf(x__4487__auto__)]);
if((!((m__4488__auto__ == null)))){
return (m__4488__auto__.cljs$core$IFn$_invoke$arity$1 ? m__4488__auto__.cljs$core$IFn$_invoke$arity$1(this$) : m__4488__auto__.call(null,this$));
} else {
var m__4485__auto__ = (pinkgorilla.editor.editor_support.frame_updated_QMARK_["_"]);
if((!((m__4485__auto__ == null)))){
return (m__4485__auto__.cljs$core$IFn$_invoke$arity$1 ? m__4485__auto__.cljs$core$IFn$_invoke$arity$1(this$) : m__4485__auto__.call(null,this$));
} else {
throw cljs.core.missing_protocol("IEditor.frame-updated?",this$);
}
}
}
});

pinkgorilla.editor.editor_support.set_frame_updated_BANG_ = (function pinkgorilla$editor$editor_support$set_frame_updated_BANG_(this$,value){
if((((!((this$ == null)))) && ((!((this$.pinkgorilla$editor$editor_support$IEditor$set_frame_updated_BANG_$arity$2 == null)))))){
return this$.pinkgorilla$editor$editor_support$IEditor$set_frame_updated_BANG_$arity$2(this$,value);
} else {
var x__4487__auto__ = (((this$ == null))?null:this$);
var m__4488__auto__ = (pinkgorilla.editor.editor_support.set_frame_updated_BANG_[goog.typeOf(x__4487__auto__)]);
if((!((m__4488__auto__ == null)))){
return (m__4488__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4488__auto__.cljs$core$IFn$_invoke$arity$2(this$,value) : m__4488__auto__.call(null,this$,value));
} else {
var m__4485__auto__ = (pinkgorilla.editor.editor_support.set_frame_updated_BANG_["_"]);
if((!((m__4485__auto__ == null)))){
return (m__4485__auto__.cljs$core$IFn$_invoke$arity$2 ? m__4485__auto__.cljs$core$IFn$_invoke$arity$2(this$,value) : m__4485__auto__.call(null,this$,value));
} else {
throw cljs.core.missing_protocol("IEditor.set-frame-updated!",this$);
}
}
}
});

pinkgorilla.editor.editor_support.compute_cursor_dx = (function pinkgorilla$editor$editor_support$compute_cursor_dx(_,change){
if(cljs.core.truth_(change)){
var ignore_QMARK_ = cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2("+indenthack",change.origin);
if(ignore_QMARK_){
return (0);
} else {
var start_x = change.to.ch;
var new_lines = change.text;
var len_last_line = cljs.core.count(cljs.core.last(new_lines));
var end_x = (((cljs.core.count(new_lines) > (1)))?len_last_line:(len_last_line + change.from.ch));
return (end_x - start_x);
}
} else {
return null;
}
});
pinkgorilla.editor.editor_support.compute_cm_change = (function pinkgorilla$editor$editor_support$compute_cm_change(cm,change,_,prev_state){
var map__52238 = (cljs.core.truth_(change)?new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"start-line","start-line",-41746654),change.from.line,new cljs.core.Keyword(null,"end-line","end-line",1837326455),(change.to.line + (1)),new cljs.core.Keyword(null,"num-new-lines","num-new-lines",-1319642646),change.text.length], null):(function (){var start = new cljs.core.Keyword(null,"cursor-line","cursor-line",-1089611007).cljs$core$IFn$_invoke$arity$1(prev_state);
var end = (start + (1));
return new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"start-line","start-line",-41746654),start,new cljs.core.Keyword(null,"end-line","end-line",1837326455),end,new cljs.core.Keyword(null,"num-new-lines","num-new-lines",-1319642646),(end - start)], null);
})());
var map__52238__$1 = (((((!((map__52238 == null))))?(((((map__52238.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__52238.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__52238):map__52238);
var start_line = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52238__$1,new cljs.core.Keyword(null,"start-line","start-line",-41746654));
var end_line = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52238__$1,new cljs.core.Keyword(null,"end-line","end-line",1837326455));
var num_new_lines = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__52238__$1,new cljs.core.Keyword(null,"num-new-lines","num-new-lines",-1319642646));
var lines = (function (){var iter__4582__auto__ = (function pinkgorilla$editor$editor_support$compute_cm_change_$_iter__52240(s__52241){
return (new cljs.core.LazySeq(null,(function (){
var s__52241__$1 = s__52241;
while(true){
var temp__5735__auto__ = cljs.core.seq(s__52241__$1);
if(temp__5735__auto__){
var s__52241__$2 = temp__5735__auto__;
if(cljs.core.chunked_seq_QMARK_(s__52241__$2)){
var c__4580__auto__ = cljs.core.chunk_first(s__52241__$2);
var size__4581__auto__ = cljs.core.count(c__4580__auto__);
var b__52243 = cljs.core.chunk_buffer(size__4581__auto__);
if((function (){var i__52242 = (0);
while(true){
if((i__52242 < size__4581__auto__)){
var i = cljs.core._nth.cljs$core$IFn$_invoke$arity$2(c__4580__auto__,i__52242);
cljs.core.chunk_append(b__52243,cm.getLine(i));

var G__52250 = (i__52242 + (1));
i__52242 = G__52250;
continue;
} else {
return true;
}
break;
}
})()){
return cljs.core.chunk_cons(cljs.core.chunk(b__52243),pinkgorilla$editor$editor_support$compute_cm_change_$_iter__52240(cljs.core.chunk_rest(s__52241__$2)));
} else {
return cljs.core.chunk_cons(cljs.core.chunk(b__52243),null);
}
} else {
var i = cljs.core.first(s__52241__$2);
return cljs.core.cons(cm.getLine(i),pinkgorilla$editor$editor_support$compute_cm_change_$_iter__52240(cljs.core.rest(s__52241__$2)));
}
} else {
return null;
}
break;
}
}),null,null));
});
return iter__4582__auto__(cljs.core.range.cljs$core$IFn$_invoke$arity$2(start_line,(start_line + num_new_lines)));
})();
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"line-no","line-no",-666819466),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [start_line,end_line], null),new cljs.core.Keyword(null,"new-line","new-line",1060819447),lines], null);
});
/**
 * Correctly format the text from the given editor.
 * @param {CodeMirror} cm
 */
pinkgorilla.editor.editor_support.fix_text_BANG_ = (function pinkgorilla$editor$editor_support$fix_text_BANG_(var_args){
var args__4795__auto__ = [];
var len__4789__auto___52251 = arguments.length;
var i__4790__auto___52252 = (0);
while(true){
if((i__4790__auto___52252 < len__4789__auto___52251)){
args__4795__auto__.push((arguments[i__4790__auto___52252]));

var G__52253 = (i__4790__auto___52252 + (1));
i__4790__auto___52252 = G__52253;
continue;
} else {
}
break;
}

var argseq__4796__auto__ = ((((1) < args__4795__auto__.length))?(new cljs.core.IndexedSeq(args__4795__auto__.slice((1)),(0),null)):null);
return pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4796__auto__);
});

(pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$core$IFn$_invoke$arity$variadic = (function (cm,p__52246){
var map__52247 = p__52246;
var map__52247__$1 = (((((!((map__52247 == null))))?(((((map__52247.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__52247.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__52247):map__52247);
var change = cljs.core.get.cljs$core$IFn$_invoke$arity$3(map__52247__$1,new cljs.core.Keyword(null,"change","change",-1163046502),null);
var current_text = cm.getValue();
var selection_QMARK_ = cm.somethingSelected();
var selections = cm.listSelections();
var cursor = cm.getCursor();
var scroller = cm.getScrollerElement();
var scroll_x = scroller.scrollLeft;
var scroll_y = scroller.scrollTop;
var options = new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"cursor-line","cursor-line",-1089611007),cursor.line,new cljs.core.Keyword(null,"cursor-x","cursor-x",475204266),cursor.ch,new cljs.core.Keyword(null,"cursor-dx","cursor-dx",133069327),pinkgorilla.editor.editor_support.compute_cursor_dx(cursor,change)], null);
var options__$1 = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([options,cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(pinkgorilla.editor.editor_support.state),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"options","options",99638489)], null))], 0));
var mode = (function (){var or__4185__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(cljs.core.deref(pinkgorilla.editor.editor_support.state),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"mode","mode",654403691)], null));
if(cljs.core.truth_(or__4185__auto__)){
return or__4185__auto__;
} else {
return new cljs.core.Keyword(null,"indent-mode","indent-mode",1737814542);
}
})();
var result = (function (){var G__52249 = mode;
var G__52249__$1 = (((G__52249 instanceof cljs.core.Keyword))?G__52249.fqn:null);
switch (G__52249__$1) {
case "indent-mode":
return pinkgorilla.editor.parinfer.indent_mode.cljs$core$IFn$_invoke$arity$2(current_text,options__$1);

break;
case "paren-mode":
return pinkgorilla.editor.parinfer.paren_mode.cljs$core$IFn$_invoke$arity$2(current_text,options__$1);

break;
default:
return null;

}
})();
var new_text = new cljs.core.Keyword(null,"text","text",-1790561697).cljs$core$IFn$_invoke$arity$1(result);
var new_cursor_x = new cljs.core.Keyword(null,"cursor-x","cursor-x",475204266).cljs$core$IFn$_invoke$arity$1(result);
cm.setValue(new_text);

if(cljs.core.truth_(selection_QMARK_)){
cm.setSelections(selections);
} else {
cm.setCursor((cursor["line"]),new_cursor_x);
}

return cm.scrollTo(scroll_x,scroll_y);
}));

(pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$lang$maxFixedArity = (1));

/** @this {Function} */
(pinkgorilla.editor.editor_support.fix_text_BANG_.cljs$lang$applyTo = (function (seq52244){
var G__52245 = cljs.core.first(seq52244);
var seq52244__$1 = cljs.core.next(seq52244);
var self__4776__auto__ = this;
return self__4776__auto__.cljs$core$IFn$_invoke$arity$variadic(G__52245,seq52244__$1);
}));


//# sourceMappingURL=pinkgorilla.editor.editor_support.js.map
